@@ -169,4 +169,8 @@ def porticus_album_list(gallery_instance, level=0):
     
     return gallery_instance.album_set.filter(level=0)
 
-register.assignment_tag(porticus_album_list)
\ No newline at end of file
+register.assignment_tag(porticus_album_list)
+
+@register.filter(name='embed')
+def embed(value):
+    return value.replace('watch?v=', 'embed/')
